pub struct RerunTaskResponse {
pub task: TaskRef,
}Fields
task: TaskRefTrait Implementations
Sourceimpl Clone for RerunTaskResponse
impl Clone for RerunTaskResponse
Sourcefn clone(&self) -> RerunTaskResponse
fn clone(&self) -> RerunTaskResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RerunTaskResponse
impl Debug for RerunTaskResponse
Sourceimpl<'de> Deserialize<'de> for RerunTaskResponse
impl<'de> Deserialize<'de> for RerunTaskResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<RerunTaskResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<RerunTaskResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RerunTaskResponse
impl JsonSchema for RerunTaskResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for RerunTaskResponse
impl Serialize for RerunTaskResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more